@@ -7,7 +7,7 @@
 
    Zile is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 2, or (at your option) any later
+   Software Foundation; either version 3, or (at your option) any later
    version.
 
    Zile is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -440,7 +440,7 @@ minibuf_read_function_name (const char *fmt, ...)
   Completion *cp;
 
   va_start (ap, fmt);
-  buf = minibuf_format (fmt, ap);
+  zvasprintf (&buf, fmt, ap);
   va_end (ap);
 
   cp = completion_new (FALSE);
@@ -482,7 +482,7 @@ minibuf_read_function_name (const char *fmt, ...)
 	    {
 	      add_history_element (&functions_history, ms);
 	      minibuf_clear ();	/* Remove any error message. */
-	      ms = zstrdup (ms);	/* Might be about to be freed. */
+	      ms = zstrdup (ms); /* Might be about to be freed. */
 	      break;		/* We're finished. */
 	    }
 	  else
@@ -684,7 +684,7 @@ message in the buffer.
         {
           g.bindings = astr_new ();
           walk_bindings (leaf_tree, gather_bindings, &g);
-          
+
           if (astr_len (g.bindings) == 0)
             minibuf_write ("%s is not on any key", name);
           else
