@@ -8,7 +8,7 @@
 
    Zile is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 2, or (at your option) any later
+   Software Foundation; either version 3, or (at your option) any later
    version.
 
    Zile is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -197,8 +197,7 @@ Marker *point_marker (void);
 Marker *point_min_marker (void);
 
 /* minibuf.c -------------------------------------------------------------- */
-extern int minibuf_written;
-char *minibuf_format (const char *fmt, va_list ap);
+extern char *minibuf_contents;
 void free_minibuf (void);
 void minibuf_error (const char *fmt, ...);
 void minibuf_write (const char *fmt, ...);
