@@ -7,7 +7,7 @@
 
    Zile is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 2, or (at your option) any later
+   Software Foundation; either version 3, or (at your option) any later
    version.
 
    Zile is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -45,12 +45,10 @@
 #include "eval.h"
 #include "vars.h"
 
-#define ZILE_VERSION_STRING	PACKAGE_NAME " " VERSION
+#define ZILE_VERSION_STRING	"GNU " PACKAGE_NAME " " VERSION
 
 #define ZILE_COPYRIGHT_STRING \
-  "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Sandro Sigala <sandro@sigala.it>\n"\
-  "Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008 Reuben Thomas <rrt@sc3d.org>\n"\
-  "Copyright (C) 2004 David A. Capello <dacap@users.sourceforge.net>"
+  "Copyright (C) 2008 Free Software Foundation, Inc."
 
 /* The current window; the first window in list. */
 Window *cur_wp = NULL, *head_wp = NULL;
@@ -263,16 +261,16 @@ main (int argc, char **argv)
 	  qflag = TRUE;
 	  break;
 	case 'v':
-	  fprintf (stderr,
+	  fprintf (stdout,
 		   ZILE_VERSION_STRING "\n"
 		   ZILE_COPYRIGHT_STRING "\n"
-		   PACKAGE_NAME " comes with ABSOLUTELY NO WARRANTY.\n"
+		   "GNU " PACKAGE_NAME " comes with ABSOLUTELY NO WARRANTY.\n"
 		   "You may redistribute copies of " PACKAGE_NAME "\n"
 		   "under the terms of the GNU General Public License.\n"
 		   "For more information about these matters, see the file named COPYING.\n");
 	  return 0;
 	case 'h':
-	  fprintf (stderr,
+	  fprintf (stdout,
 		   "Usage: " PACKAGE " [OPTION-OR-FILENAME]...\n"
 		   "\n"
 		   "Run " PACKAGE_NAME ", the lightweight Emacs clone.\n"
@@ -287,7 +285,9 @@ main (int argc, char **argv)
 		   "--version              display version information and exit\n"
 		   "\n" "Action options:\n" "\n"
 		   "FILE                   visit FILE using find-file\n"
-		   "+LINE FILE             visit FILE using find-file, then go to line LINE\n");
+		   "+LINE FILE             visit FILE using find-file, then go to line LINE\n"
+		   "\n"
+		   "Report bugs to " PACKAGE_BUGREPORT ".\n");
 	  return 0;
 	case '?':		/* Unknown option */
 	  minibuf_error ("Unknown option `%s'", argv[this_optind]);
@@ -347,12 +347,23 @@ main (int argc, char **argv)
 	    }
 	}
 
-      if (!minibuf_written && argc == 0 && list_length (fargs) == 0)
-	/* Show the splash screen only if no files and no Lisp expression
-	   or load file is specified on the command line. */
+      /* Show the splash screen only if no files and no Lisp expression
+         or load file is specified on the command line. */
+      if (minibuf_contents == NULL && argc == 0 && list_length (fargs) == 0)
 	about_screen ();
 
       setup_main_screen (argc);
+
+      /* Refresh minibuffer in case there's an error that couldn't be
+	 written during startup */
+      if (minibuf_contents != NULL)
+	{
+	  char *buf = zstrdup (minibuf_contents);
+
+	  minibuf_write (buf);
+	  free (buf);
+	}
+
       execute_functions (fargs);
       list_delete (fargs);
 
@@ -365,6 +376,12 @@ main (int argc, char **argv)
 
       free_bindings ();
     }
+  else if (minibuf_contents) /* if in batch mode, print any error */
+    {
+      fputs (PACKAGE ": ", stderr);
+      fputs (minibuf_contents, stderr);
+      fputc ('\n', stderr);
+    }
 
   /* Free Lisp state. */
   variableFree (mainVarList);
