@@ -237,28 +237,28 @@ extern reg_syntax_t re_syntax_options;
    `re_error_msg' table in regex.c.  */
 typedef enum
 {
-  REG_NOERROR = 0,	/* Success.  */
-  REG_NOMATCH,		/* Didn't find a match (for regexec).  */
+  REG_NOERROR = 0,		/* Success.  */
+  REG_NOMATCH,			/* Didn't find a match (for regexec).  */
 
   /* POSIX regcomp return error codes.  (In the order listed in the
      standard.)  */
-  REG_BADPAT,		/* Invalid pattern.  */
-  REG_ECOLLATE,		/* Not implemented.  */
-  REG_ECTYPE,		/* Invalid character class name.  */
-  REG_EESCAPE,		/* Trailing backslash.  */
-  REG_ESUBREG,		/* Invalid back reference.  */
-  REG_EBRACK,		/* Unmatched left bracket.  */
-  REG_EPAREN,		/* Parenthesis imbalance.  */
-  REG_EBRACE,		/* Unmatched \{.  */
-  REG_BADBR,		/* Invalid contents of \{\}.  */
-  REG_ERANGE,		/* Invalid range end.  */
-  REG_ESPACE,		/* Ran out of memory.  */
-  REG_BADRPT,		/* No preceding re for repetition op.  */
+  REG_BADPAT,			/* Invalid pattern.  */
+  REG_ECOLLATE,			/* Not implemented.  */
+  REG_ECTYPE,			/* Invalid character class name.  */
+  REG_EESCAPE,			/* Trailing backslash.  */
+  REG_ESUBREG,			/* Invalid back reference.  */
+  REG_EBRACK,			/* Unmatched left bracket.  */
+  REG_EPAREN,			/* Parenthesis imbalance.  */
+  REG_EBRACE,			/* Unmatched \{.  */
+  REG_BADBR,			/* Invalid contents of \{\}.  */
+  REG_ERANGE,			/* Invalid range end.  */
+  REG_ESPACE,			/* Ran out of memory.  */
+  REG_BADRPT,			/* No preceding re for repetition op.  */
 
   /* Error codes we've added.  */
-  REG_EEND,		/* Premature end.  */
-  REG_ESIZE,		/* Compiled pattern bigger than 2^16 bytes.  */
-  REG_ERPAREN		/* Unmatched ) or \); not returned from regcomp.  */
+  REG_EEND,			/* Premature end.  */
+  REG_ESIZE,			/* Compiled pattern bigger than 2^16 bytes.  */
+  REG_ERPAREN			/* Unmatched ) or \); not returned from regcomp.  */
 } reg_errcode_t;
 
 /* This data structure represents a compiled pattern.  Before calling
@@ -270,67 +270,67 @@ typedef enum
 struct re_pattern_buffer
 {
 /* [[[begin pattern_buffer]]] */
-	/* Space that holds the compiled pattern.  It is declared as
-          `unsigned char *' because its elements are
-           sometimes used as array indexes.  */
+  /* Space that holds the compiled pattern.  It is declared as
+     `unsigned char *' because its elements are
+     sometimes used as array indexes.  */
   unsigned char *buffer;
 
-	/* Number of bytes to which `buffer' points.  */
+  /* Number of bytes to which `buffer' points.  */
   unsigned long allocated;
 
-	/* Number of bytes actually used in `buffer'.  */
+  /* Number of bytes actually used in `buffer'.  */
   unsigned long used;
 
-        /* Syntax setting with which the pattern was compiled.  */
+  /* Syntax setting with which the pattern was compiled.  */
   reg_syntax_t syntax;
 
-        /* Pointer to a fastmap, if any, otherwise zero.  re_search uses
-           the fastmap, if there is one, to skip over impossible
-           starting points for matches.  */
+  /* Pointer to a fastmap, if any, otherwise zero.  re_search uses
+     the fastmap, if there is one, to skip over impossible
+     starting points for matches.  */
   char *fastmap;
 
-        /* Either a translate table to apply to all characters before
-           comparing them, or zero for no translation.  The translation
-           is applied to a pattern when it is compiled and to a string
-           when it is matched.  */
+  /* Either a translate table to apply to all characters before
+     comparing them, or zero for no translation.  The translation
+     is applied to a pattern when it is compiled and to a string
+     when it is matched.  */
   char *translate;
 
-	/* Number of subexpressions found by the compiler.  */
+  /* Number of subexpressions found by the compiler.  */
   size_t re_nsub;
 
-        /* Zero if this pattern cannot match the empty string, one else.
-           Well, in truth it's used only in `re_search_2', to see
-           whether or not we should use the fastmap, so we don't set
-           this absolutely perfectly; see `re_compile_fastmap' (the
-           `duplicate' case).  */
-  unsigned can_be_null : 1;
+  /* Zero if this pattern cannot match the empty string, one else.
+     Well, in truth it's used only in `re_search_2', to see
+     whether or not we should use the fastmap, so we don't set
+     this absolutely perfectly; see `re_compile_fastmap' (the
+     `duplicate' case).  */
+  unsigned can_be_null:1;
 
-        /* If REGS_UNALLOCATED, allocate space in the `regs' structure
-             for `max (RE_NREGS, re_nsub + 1)' groups.
-           If REGS_REALLOCATE, reallocate space if necessary.
-           If REGS_FIXED, use what's there.  */
+  /* If REGS_UNALLOCATED, allocate space in the `regs' structure
+     for `max (RE_NREGS, re_nsub + 1)' groups.
+     If REGS_REALLOCATE, reallocate space if necessary.
+     If REGS_FIXED, use what's there.  */
 #define REGS_UNALLOCATED 0
 #define REGS_REALLOCATE 1
 #define REGS_FIXED 2
-  unsigned regs_allocated : 2;
+  unsigned regs_allocated:2;
 
-        /* Set to zero when `regex_compile' compiles a pattern; set to one
-           by `re_compile_fastmap' if it updates the fastmap.  */
-  unsigned fastmap_accurate : 1;
+  /* Set to zero when `regex_compile' compiles a pattern; set to one
+     by `re_compile_fastmap' if it updates the fastmap.  */
+  unsigned fastmap_accurate:1;
 
-        /* If set, `re_match_2' does not return information about
-           subexpressions.  */
-  unsigned no_sub : 1;
+  /* If set, `re_match_2' does not return information about
+     subexpressions.  */
+  unsigned no_sub:1;
 
-        /* If set, a beginning-of-line anchor doesn't match at the
-           beginning of the string.  */
-  unsigned not_bol : 1;
+  /* If set, a beginning-of-line anchor doesn't match at the
+     beginning of the string.  */
+  unsigned not_bol:1;
 
-        /* Similarly for an end-of-line anchor.  */
-  unsigned not_eol : 1;
+  /* Similarly for an end-of-line anchor.  */
+  unsigned not_eol:1;
 
-        /* If true, an anchor at a newline matches.  */
-  unsigned newline_anchor : 1;
+  /* If true, an anchor at a newline matches.  */
+  unsigned newline_anchor:1;
 
 /* [[[end pattern_buffer]]] */
 };
@@ -369,8 +369,8 @@ struct re_registers
    structure of arrays.  */
 typedef struct
 {
-  regoff_t rm_so;  /* Byte offset from string's start to substring's start.  */
-  regoff_t rm_eo;  /* Byte offset from string's start to substring's end.  */
+  regoff_t rm_so;		/* Byte offset from string's start to substring's start.  */
+  regoff_t rm_eo;		/* Byte offset from string's start to substring's end.  */
 } regmatch_t;
 
 /* Declarations for routines.  */
@@ -389,8 +389,7 @@ extern reg_syntax_t re_set_syntax (reg_syntax_t syntax);
    and syntax given by the global `re_syntax_options', into the buffer
    BUFFER.  Return NULL if successful, and an error string if not.  */
 extern const char *re_compile_pattern
-  (const char *pattern, int length,
-   struct re_pattern_buffer *buffer);
+  (const char *pattern, int length, struct re_pattern_buffer *buffer);
 
 
 /* Compile a fastmap for the compiled pattern in BUFFER; used to
@@ -427,8 +426,8 @@ extern int re_match
 /* Relates to `re_match' as `re_search_2' relates to `re_search'.  */
 extern int re_match_2
   (struct re_pattern_buffer *buffer, const char *string1,
-    int length1, const char *string2, int length2,
-    int start, struct re_registers *regs, int stop);
+   int length1, const char *string2, int length2,
+   int start, struct re_registers *regs, int stop);
 
 
 /* Set REGS to hold NUM_REGS registers, storing them in STARTS and
@@ -445,8 +444,8 @@ extern int re_match_2
    freeing the old data.  */
 extern void re_set_registers
   (struct re_pattern_buffer *buffer, struct re_registers *regs,
-    unsigned num_regs, regoff_t *starts, regoff_t *ends);
+   unsigned num_regs, regoff_t * starts, regoff_t * ends);
 
-extern void regfree (regex_t *preg);
+extern void regfree (regex_t * preg);
 
 #endif /* not __REGEXP_LIBRARY_H__ */
